@@ -13,7 +13,7 @@ use Astro::App::Satpass2::Utils qw{
     @CARP_NOT
 };
 
-our $VERSION = '0.049';
+our $VERSION = '0.049_01';
 
 use constant DEFAULT_LOCAL_COORD => 'azel_rng';
 
@@ -666,7 +666,7 @@ ad-hoc.
 The C<$data> argument is expected to be a reference to an array of
 L<Astro::Coord::ECI::TLE|Astro::Coord::ECI::TLE> objects. The output
 should be compatible with the normal TLE format as documented at
-L<http://celestrak.com>.
+L<http://celestrak.org>.
 
 =item tle_verbose
 
@@ -770,7 +770,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2021 by Thomas R. Wyant, III
+Copyright (C) 2010-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
