@@ -11,7 +11,7 @@ use Astro::Coord::ECI::TLE 0.059 qw{ :constants };
 use Astro::App::Satpass2::Utils qw{ @CARP_NOT };
 use Scalar::Util ();
 
-our $VERSION = '0.049';
+our $VERSION = '0.049_01';
 
 my @event_names;
 $event_names[PASS_EVENT_NONE]		= '';
@@ -227,7 +227,8 @@ EOD
 	pass_ics	=> <<'EOD',
 [% UNLESS data %]
     [%- SET data = sp.pass( arg ) %]
-[%- END -%]
+[%- END %]
+[%- SET do_mag = sp.want_pass_variant( 'brightest' ) -%]
 BEGIN:VCALENDAR
 VERSION:2.0
 [%- FOR pass IN data %]
@@ -261,7 +262,7 @@ DESCRIPTION:
 	[%- IF 'rise' != evt_name and 'set' != evt_name %] Ele
 	    [%= evt.elevation( places = 0 ) %]
 	[%- END %]
-	[%- IF '' != evt.magnitude %] Mag
+	[%- IF do_mag && '' != evt.magnitude %] Mag
 	    [%= evt.magnitude %]
 	[%- END %]
         [%- punct = '\n' %]
@@ -697,7 +698,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2021 by Thomas R. Wyant, III
+Copyright (C) 2014-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
