@@ -14,7 +14,7 @@ use Getopt::Long 2.33;
 use Scalar::Util 1.26 qw{ blessed looks_like_number };
 use Text::ParseWords ();
 
-our $VERSION = '0.049';
+our $VERSION = '0.049_01';
 
 our @CARP_NOT = qw{
     Astro::App::Satpass2
@@ -88,8 +88,32 @@ use constant SCALAR_REF	=> ref \1;
 	    has_method( $_, 'dereference' ) ?  $_->dereference() : $_
 	} @args;
 
+	my $code = \&{ ( caller 1 )[3] };
+
 	if ( HASH_REF eq ref $args[0] ) {
 	    my $opt = shift @args;
+	    my @orig_keys = sort keys %{ $opt };
+	    my $lgl = $self->__legal_options( $code, $opt );
+	    my %opt_name = (
+		level1	=> 1,
+	    );
+	    my $name;
+	    foreach my $inx ( 0 .. $#$lgl ) {
+		if ( CODE_REF eq ref $lgl->[$inx] ) {
+		    defined $name
+			or die "Bug - \$name undefined. Inx $inx; lgl @$lgl";
+		    if ( exists $opt->{$name} ) {
+			$lgl->[$inx]->( $name, $opt->{$name} );
+		    }
+		} else {
+		    ( $name = $lgl->[ $inx ] ) =~ s/ \W .* //smx;
+		    $opt_name{$name} = 1;
+		}
+	    }
+	    foreach my $key ( @orig_keys ) {
+		$opt_name{$key}
+		    or __error_out( $self, wail => "Illegal option '$key'" );
+	    }
 	    _apply_default( $self, $opt, \@args );
 	    return( $self, $opt, @args );
 	}
@@ -116,7 +140,6 @@ use constant SCALAR_REF	=> ref \1;
 
 
 	my ( $err, %opt );
-	my $code = \&{ ( caller 1 )[3] };
 	my $lgl = $self->__legal_options( $code, \%opt );
 
 	local $SIG{__WARN__} = sub {$err = $_[0]};
@@ -877,7 +900,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2021 by Thomas R. Wyant, III
+Copyright (C) 2011-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
